@@ -24,12 +24,12 @@ from systembridgeshared.settings import Settings
 from systembridgeshared.websocket_client import WebSocketClient
 from typer import Typer
 
-from systembridgegui._version import __version__
-from systembridgegui.system_tray import SystemTray
-from systembridgegui.widgets.timed_message_box import TimedMessageBox
-from systembridgegui.window.main import MainWindow
-from systembridgegui.window.notification import NotificationWindow
-from systembridgegui.window.player import PlayerWindow
+from ._version import __version__
+from .system_tray import SystemTray
+from .widgets.timed_message_box import TimedMessageBox
+from .window.main import MainWindow
+from .window.notification import NotificationWindow
+from .window.player import PlayerWindow
 
 
 class Main(Base):
@@ -101,7 +101,7 @@ class Main(Base):
                 self._startup_error("No data provided!")
                 sys.exit(1)
             media_play = MediaPlay(**data)
-            self._player_window = PlayerWindow(
+            self._main_window = PlayerWindow(
                 self._settings,
                 self._icon,
                 self._application,
@@ -115,7 +115,7 @@ class Main(Base):
                 self._startup_error("No data provided!")
                 sys.exit(1)
             media_play = MediaPlay(**data)
-            self._player_window = PlayerWindow(
+            self._main_window = PlayerWindow(
                 self._settings,
                 self._icon,
                 self._application,
@@ -128,7 +128,7 @@ class Main(Base):
                 self._logger.error("No data provided!")
                 self._startup_error("No data provided!")
                 sys.exit(1)
-            self._player_window = NotificationWindow(
+            self._main_window = NotificationWindow(
                 self._settings,
                 self._icon,
                 self._application,
